@@ -5,17 +5,18 @@ Before using other language you must set
 """
 import os
 
-LANGUAGE = os.environ.get("SELENIUM-ODOO-PAGE-LANGUAGE", "en")
 TERMS = {
     "fr": {
         "Create and Edit...": "Créer et modifier...",
         "Create Invoice": "Créer une facture",
         "Confirm": "Confirmer",
+        "Sales": "Ventes",
     },
 }
 
 
 def get_term(label):
-    if LANGUAGE == "en":
+    language = os.environ.get("SELENIUM_ODOO_PAGE_LANGUAGE", "en")
+    if language == "en":
         return label
-    return TERMS[LANGUAGE][label]
+    return TERMS[language][label]
