@@ -31,11 +31,27 @@ class SearchViewMixin:
         self.search_menu_el.close()
 
     def add_filter(self, search_pattern, element=None, expected_value=None):
-        if element is not None:
-            if not expected_value:
-                expected_value = search_pattern
-            raise NotImplementedError()
+        """Add filter using auto completion
+
+        search_pattern: the value to search typed by the user
+        element: element used for autocompletion or direct search
+        expected_value: search value in case of element is autocompleted fields
+          require element params
+        """
+        if expected_value and not element:
+            raise ValueError(
+                f"element parameter is mandatory while providing expected_value: {expected_value}."
+                "element is used to choose from which field you want auto-completion"
+            )
         self.search_bar_el = search_pattern
+        if element is not None:
+            self.wait_loading()
+            self.search_bar_el.click_item(element, expand=bool(expected_value))
+            if expected_value:
+                self.wait_loading()
+                self.search_bar_el.click_item(expected_value)
+        else:
+            self.search_bar_el.enter()
         self.wait_loading()
 
     def clear_filters(self):
@@ -45,7 +61,10 @@ class SearchViewMixin:
 
 class FormViewMixinLocators:
     CREATE_BUTTON = (By.CSS_SELECTOR, "button.o_form_button_create")
-    SAVE_BUTTON = (By.CSS_SELECTOR, "button.o_form_button_save")
+    SAVE_BUTTON = (
+        By.CSS_SELECTOR,
+        "button.o_form_button_save, button.o_list_button_save",
+    )
     EDIT_BUTTON = (By.CSS_SELECTOR, "button.o_form_button_edit")
 
     TAB_TEMPLATE = (
